@@ -12,5 +12,5 @@ from .urlManager import *
 from .userAgentManager import *
 from .seleneumManager import *
 from .videoDownloader import *
-from .middleManager import *
+from .middleManager import get_soup_tools,get_req_tools,get_url_tools
 seleniumManager = seleneumManager
