@@ -5,7 +5,7 @@ def get_ua_mgr(
          version=None,
          user_agent=None,
          randomAll=False,
-         randomAOperatingSystem=False,
+         randomOperatingSystem=False,
          randomBrowser=False,
          ua_mgr=None
          ):
@@ -15,7 +15,7 @@ def get_ua_mgr(
          version=version,
          user_agent=user_agent,
          randomAll=randomAll,
-         randomAOperatingSystem=randomAOperatingSystem,
+         randomOperatingSystem=randomOperatingSystem,
          randomBrowser=randomBrowser)
 def get_user_agent_headers(
          operating_system=None,
@@ -23,7 +23,7 @@ def get_user_agent_headers(
          version=None,
          user_agent=None,
          randomAll=False,
-         randomAOperatingSystem=False,
+         randomOperatingSystem=False,
          randomBrowser=False,
          ua_mgr=None
          ):
@@ -34,6 +34,6 @@ def get_user_agent_headers(
          version=version,
          user_agent=user_agent,
          randomAll=randomAll,
-         randomAOperatingSystem=randomAOperatingSystem,
+         randomOperatingSystem=randomOperatingSystem,
          randomBrowser=randomBrowser)
     return ua_mgr.get_user_agent_headers()
