@@ -179,8 +179,8 @@ class VideoDownloader:
                  registry=None, force_refresh=False,
                  flat_layout: bool = False,video_url =None):
 
-        self.url = get_corrected_url(url or video_url) 
-        self.video_urls = self.url if isinstance(self.url, list) else [self.url]
+        self.video_url = self.url = get_corrected_url(url or video_url) 
+        self.video_urls = self.url if isinstance(self.video_url, list) else [self.url]
 
         self.registry = registry or infoRegistry(video_root=download_directory,flat_layout=flat_layout)
         self.ydl_opts = ydl_opts or {}
@@ -258,10 +258,9 @@ class VideoDownloader:
                          video_path=None, output_filename=None, ydl_opts=None,
                          registry=None, force_refresh=False,
                          flat_layout: bool = False,video_url =None):
-         url = get_corrected_url(url or video_url or self.url) 
+         video_url = url = get_corrected_url(url or video_url or self.url or self.video_url) 
 
          ydl_opts = ydl_opts or self.ydl_opts or {}
-         get_download = get_download or self.get_download
          user_agent = user_agent or self.user_agent
          
          force_refresh = force_refresh or self.force_refresh
@@ -288,7 +287,7 @@ class VideoDownloader:
              flat_layout=flat_layout
              )
          logger.info(f"[VideoDownloader] Processing: {video_url}")
-         self.url = get_corrected_url(url or video_url or self.url) 
+         video_url = get_corrected_url(url or video_url or self.url or self.video_url) 
          if "youtube.com/watch" in video_url and "v=" not in video_url:
             logger.debug(f"[VideoDownloader] Skipping bare watch URL: {video_url}")
             return None
@@ -350,7 +349,7 @@ def get_videoDownloader(url=None,
                    force_refresh=False,
                    flat_layout: bool = False,
                    video_url=None):
-    videoDownload_mgr = get_videoDownloader(
+    videoDownload_mgr = VideoDownloader(
         url=url,
         download_directory=download_directory,
         user_agent=user_agent,
